/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvSignalEnvelope.h"
#include "HvSignalLine.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvControlIf.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlCast.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_CJfbewjo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bhgo4rlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P1xryvde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TYYfV0g9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SSJIXKAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PBJV9Jjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cpp1cYvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BZGpjnch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hBPzmuj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iZJLr9Bh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sWdbvfJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ad4g4tD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qw1oOd7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Bp12rv1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K3L7cDVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KPE6WbBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZxGTACkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6eSMoMui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_urDVnMk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hP2cPhAb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Sew3KMu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_e3TZAFXD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_TyFVOS3Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fgJeaEv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YqxISkPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O31nWhTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Rpp6UmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6IJ3vl1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_irkEcFyh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Djx6E2VE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pp4jpsm7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_xCadc2rA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8A0DEZhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VOmiQiCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SXj758vo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jb7daM3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_reDI3qtc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8xweh5zJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2S72RUAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d6fJ2vIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MQhQihwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N8Ft7lbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pUumfgqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_giuFUnjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YKKZ7fPp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dGX1hzBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A0CdaP09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u0WXRQLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2PeuS9Ak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aK3Bi4Db_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mgDxdtlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uFQ5Idtz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bnVxAkP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iHMoLy8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SOeoeAkf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jIg6ePBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4dyqPBal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qrZdNhm9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7CoNZ39N_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_b9sB6Wvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EMupfa2K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YIMK6wcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H9nAKHp4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NDAdOxRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUKbuYSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z2Qi2pnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VJl3iitP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jHHduX9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1UWjtgma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WA5MYRYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IuLFcvHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LX6UsjdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jLpamAz9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wjl2CGSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wUqr38w8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LGWfqdL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sfoXSWPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K8yaB7jS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9p5W2y5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lC6hSIQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sxCBdWJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UjxkVVME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FlK4jegf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ExQDfTRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YZmdeB4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MJt2r5UR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pYbtVQzA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_p40uQBlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uNcqS8pk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t04Am45Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kk9KoNEM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gyIazyAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DYU5yjXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LQahEAcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RFpkOeP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XKtVEWbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VktrF4AH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eamLSx3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7YRG8p0d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y5etk4oe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5B1r3JvB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_S5r1va5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gxp2lLyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mu9Xwmv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kx7l0EiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2blo2804_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pG3waefX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YTumkDXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_diKLAlMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YRfGgO13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M6KxKonD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r7qOvP7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K05poGQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nRlQgVqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wRKcFL3F_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_o5T7LAJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uHcvGNon_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lgzfVKpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fikMKrAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zpCEHfz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q946YAog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6BFpwvd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EPGQf6KM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8uPX1OMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fsr4PrMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nda98IAc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_50ycFLMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_j1oPLOa4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pRCdgkX8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JDGE43GF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WkfBwyoK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NeXXRCKB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iJUfwGsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EysYMhZU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BGSRe7ei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NEbc2cyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fXrDVuN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i5bVq0AT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4MT52PME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_myt3laoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BV53qg7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fFeOeICo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_h5qSOe1j_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_BI7jDGIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KmpiAgmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WuRyxTal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nmhagRob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FSnKuMfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8mLMHG6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QcjdzoEt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EBW7AJCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ui0ommLY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1MdeqFib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oT41aAUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UTNoZLsk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EemWsL5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wCr1XH9X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_e80tJhkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8npa41Vh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_14y6ZQLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MoXFiG1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i6b1gx1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r1MUFb8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XdbbDuju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2L5ksgTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WuPbVIiw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UfI38h2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LbSc52Md_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xesHqTwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_B0MvydKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Pge9XQ9c_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_QV2qRSzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lUuBcvn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VxBs7IDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nj4g7Q9s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vrraKAPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CgTO8ySP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g9V3SHfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uYjXETN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C4SPpCw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8wednO6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X0hG1Ri4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Y2B4lL0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_i6WwzSkI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IwpsywY6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1hOVMjtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P1c7vA7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v0xt4Lkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6AkJlPAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aFaYrjzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oFTIpofi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HtxMHdwi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aVYcg9ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pKFhaLp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dIBrBFOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PaGUoMVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jH63nkr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iTiUUqF7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aLsI4I4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sDxXajsJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5nDq21mO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5NrQMh6U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NdAxZ4WT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DmX8xaFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9D7uxIwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_srSiTiw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YoA4mexV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3XQfzO6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D3NjIgim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zw3Cixhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9NAX0jOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Js27SZfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nYuR3Djq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HSNaaw0d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cmcofGY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l1xzOMem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HRuwCEEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MuIHMCSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H0xYCr62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PG1Fj7Xw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oorqvb6P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vbedpvhW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5FAKKCgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P18NX9B5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aNPboW80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wtVIQw5Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PLoWGokC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WvvEKdM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fSw8uuVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bKPCfqTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_faA1hC8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zxrDve35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rlopynJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_44RqSbgT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0s5aNX5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GYtgHz8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eOcSwJc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZaI4N2Ul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9ltt4MLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KWwUqXHH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lP2XrYJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_o6TLV7Lf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_hVkJdJqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UdYKh2S1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xro9oqlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_R4KhDNRS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_eJgTnml8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_N2e0gyY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BNna4SJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UJ2DsykM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YuiDO7Wj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_21FAwV3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AijXjQXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2QhIGi31_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_rnuUbCas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Hx3Wvl5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_v1HoiZpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XGcKKeaz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cXCkPcAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CnfQq3nG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wgLitw1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GFqd6FJG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RBcLyU2w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ttbka1MP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QM6OL9xb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2CLBVDxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4anr0KIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_J2q37tsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_R9UclOj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_xgqaJSNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iIGGn1Wj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9XcQoZr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j1eJnH2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KADHKFkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YlIN8gq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_syI7KuAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yrpdvJ1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fcacVDeD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wK3ZW7i2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lSXtDgSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C51Fr1Dx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KmGdDsAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rzHEJScw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_L1pIL8qo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LA3VWI7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cYsHAiuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Ocl2XZ8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dEUKWGrE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HYJkjZwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7bnmjmpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tgsVKD6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I2dV3F2u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AZb2Ioax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wpugiIKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vOkUulgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xlCVP3QY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nzdni5ow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f84Beymj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HMnAlBuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FnuJQHRA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CckwPojq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_tE787RUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_piWXMc5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NKrzeAEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XhMWIFrp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O6TEEsd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VNnc5QVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JzQGadkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kADh4Sti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mg8mh2dJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tfj1NevL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rujg9HNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pTuUrGHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Pomcwto_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SDcAhrDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WlpLqk5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rFVRTjlN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DNlmPTIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_57n5jYiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_77HiJ0dB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7QJEBas7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iP1GBP3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CTwsqfLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bdVz0LhV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_uWV8Ykq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZSjk7Bqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rW04Bnr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wdpKLAz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HZUL2knp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TgatKY35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EeXF9tyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SoYe5plY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6RpUyueH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UjuAwxxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2TwyDQE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kOWUCxEW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_01yrIbDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dSlWkijD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_SWehebqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zLEuwJZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TALVJEzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JTUIITS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_glTuV18D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZgNDgNr9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QmO3zEdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aktELYm9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9aW42u7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Xyog3Fa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vYZ97wuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EIFBqTeK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7Gos6AWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_J1hpNM08_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_PlrDjp5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3i3sRcxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WBwvxWuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1G6smgVu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y5kmGigU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rkDlijiJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zpHGcFJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_edrJfmvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sw8U10G2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rTWfet5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Ii8cJ0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wyPfNtf8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5SVbwh2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_l1yjxHcw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7rTfuvRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BnrmPY6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KzPzKmvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rMQvKfVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q6ZOKsUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_einDfqyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7MC0k2vs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4mQDpwXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ANeW4sfv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qm9cD5jD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dFqS4Ppc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Cij4FRDB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pd4dg6KT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lBG0AsOT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_nx1tJuYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jjylMrvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5H8OSF2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_etWyGKao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CeLuwTZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D4GD9dkc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lCIk3zrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pJ5KrLas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1VVPF4cX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SCOxU634_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x7dgEFSm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hiuEtWaY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3SQgAcGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_al0i5JNH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ffcqMVKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7HK1CM49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ybl2zow2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jbpJN7M0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qKFEDVZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1fqAnVSc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OOTf9391_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zAiQCaQJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DwuGPsdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LbBLTDHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n3tH8Ils_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gqWhXAIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iHBn8rjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jrz0YuR1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_zcvl9Vi0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j95obQ1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gUkLQuv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eD2FbFCE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5WUg4Cpc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hdBzrGh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0S1bGVOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kvfEknPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dhSpKSCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g5KzRXKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XyrRZx0J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jHE3H9f3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YHH8vyd3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aeV6Q5e6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_qkmz6RaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wHyQXbZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SgPnomqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2nJdIBkB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rplHiNMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EEeHLW2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L3PKnwHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gCgN5CtJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NBRePqwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PLB5CFlX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_supEZNyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Qi42PV8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kQGzDWjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SoXrjj2F_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_N5DcpNcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PwTkuLrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rVq3NeQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ysIkndrV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zAZChsvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kgzMwyH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J9Xy9nq7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W2om1JaY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OfgCaJr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nu92up47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cHmwINl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YPIwiWDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fUiwAgbF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_23HyU0ba_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RNKX6ckp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I86PnVcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c3WLdw6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UDzaoJCE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_08Gt7C9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_clSEuSWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jEuy6Nuq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2tuO6E8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Px1hnbTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vtDay2m6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sINUk5J6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tAkLA30h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RJxrRSkX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_o10Aiekd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_HQMG3m7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_05XSjj6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QGpbyzq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xO7FBSGT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GyQMi8Ck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZCPpI305_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oi668Qco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gI0dIcWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ETj2Fjgi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4hjH8xtR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fWapIbC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KSGnFGrx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OTuFklVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MF4NSLVl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BsYFAULd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hwy7osvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d4P1rBOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rspFzMaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9jinSTp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cO3x9aN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IiMvYDVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xY7Zvbf1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dz5hZ18L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LdzoqQrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g9Rf5IDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4HeDoSOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6WEZNzCb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_myoKichI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FBaX7lrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PEIJ7WKL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2xMgZU0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vMM3HbIx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qi5SH1Tt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4asWwMT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y7GJUgAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xD1ra5GQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B27j5uXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fP8p20MC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dLjb0XkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8IXuqssM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XjmTEUPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KcciVs0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aXPdczoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JoHeOlVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a50TGgrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uiidYKif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WYbHIdIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O2pbO4t0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PiXOjHD6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1piB4gCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mTL6KbGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xx8igZ4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4htL5hQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hVYE8D6z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1Yi9reGh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bqjKPRW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OoiM5YRI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AQ2bR2zH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Jx7A37oC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rC36cThs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_h9pszr9F_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_O5WcNKU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rmbjTk5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZvdODmV0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q8ioqz1e_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_P3HLEH9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_220V1Jqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Q8Rnpfrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TWLP14vP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_NEoq435u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_g5BLJDGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6e6XDICU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Dzky21rS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_VOU2CHCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XvHvUROh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZsBJgndV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xLtqE26B_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_eSX8jz2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1fifEUc0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_duzacJxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WlxC5ed9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zuIYvkys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_l8oB29G0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_ouK9S1KB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_rotnfrtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UGMok14j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wx1LBhlt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Ro05PIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E0E4UOks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ApCY9a0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fNzNZFOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s89ZcETr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c03AdUuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dkt7H96A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kLetmaVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fRIxZJjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LGMTq4nl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PkXnIeAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dQqzG6Bi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_uPURAV4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_k6Y8dNux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UKb8RdOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cJwfOaTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HZ7FFh8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gvHfpo3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xhKoO9si_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u374dMwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rUuxlmkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GBBRbgGe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y5o85hxS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GIqzkNrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hauiRKJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u1l1SnQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z0YDg9jS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aHEujlDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCniOfpc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_b9eYlJRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S5pAySuZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ncQDjVor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_es3X3pCb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7lJH6zmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RER5qTVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sRPV4efD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PvSvbmbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ovuXDhRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ufaOmK46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EdK3EMNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tWGQwAj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PavbT31b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HUTQCdhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tRwnpZbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JMDq8a2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VpYjGlCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Y38LknwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GjHBESxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6KQH6Ilx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zJ9c7FPs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lCdH0NQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2xW5sHXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EddwNtx7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_F2zboOao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aOq7EAxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yaMSJyND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_L3khMqsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7DWzgcpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fs73XspK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3oT5hjM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ur2Rh5Jr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pu57HRiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tKopam3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_q8MkeRKO;
  SignalLine sLine_otOWOpJ7;
  SignalLine sLine_XsnCBmlt;
  SignalLine sLine_xYl5Su7R;
  SignalLine sLine_aLQuIkHV;
  SignalLine sLine_M5ttHUpD;
  SignalLine sLine_bQAebMe3;
  SignalLine sLine_MqfmrIxs;
  SignalLine sLine_l0OzIrTy;
  SignalLine sLine_1IXBNWJd;
  SignalLine sLine_IPN5JjOz;
  SignalLine sLine_tHxJObVu;
  SignalEnvelope sEnv_R9UclOj1;
  SignalEnvelope sEnv_xgqaJSNm;
  SignalLine sLine_LzW3mqdc;
  SignalLine sLine_Q0PVSnmY;
  SignalLine sLine_6AAo6b07;
  SignalLine sLine_mzjCEywJ;
  SignalLine sLine_i0nzeinK;
  SignalLine sLine_BH9kx8YD;
  SignalLine sLine_bQ0kpNnr;
  SignalLine sLine_B0pySYnI;
  SignalLine sLine_Y6ESugOK;
  SignalLine sLine_EeBrS2vd;
  SignalLine sLine_5rRzxRcN;
  SignalLine sLine_qQ7AsD85;
  SignalLine sLine_QzJkzyZe;
  SignalLine sLine_bkBl3tvW;
  SignalLine sLine_WzQRmHWI;
  SignalLine sLine_EYFosEBW;
  SignalLine sLine_80XnqXPw;
  SignalLine sLine_UROws83r;
  SignalEnvelope sEnv_ouK9S1KB;
  SignalEnvelope sEnv_rotnfrtt;
  SignalLine sLine_IjH9wthD;
  SignalLine sLine_pbqNZFGQ;
  SignalLine sLine_j5S8jlwG;
  SignalLine sLine_VFSkVAJK;
  SignalLine sLine_2fDiwNIV;
  SignalLine sLine_Qi3CztTI;
  SignalLine sLine_1WnE3hWo;
  SignalLine sLine_fhTOrb2x;
  ControlVar cVar_CJfbewjo;
  ControlBinop cBinop_Bhgo4rlB;
  ControlBinop cBinop_P1xryvde;
  ControlBinop cBinop_TYYfV0g9;
  ControlBinop cBinop_SSJIXKAs;
  ControlBinop cBinop_BZGpjnch;
  ControlBinop cBinop_iZJLr9Bh;
  ControlBinop cBinop_sWdbvfJB;
  ControlBinop cBinop_Ad4g4tD5;
  ControlVar cVar_qw1oOd7z;
  ControlVar cVar_Bp12rv1s;
  ControlVar cVar_K3L7cDVs;
  ControlVar cVar_KPE6WbBU;
  ControlVar cVar_ZxGTACkV;
  ControlBinop cBinop_6eSMoMui;
  ControlVar cVar_hP2cPhAb;
  ControlVar cVar_Sew3KMu5;
  ControlIf cIf_irkEcFyh;
  ControlIf cIf_Djx6E2VE;
  ControlDelay cDelay_xCadc2rA;
  ControlBinop cBinop_SXj758vo;
  ControlBinop cBinop_Jb7daM3U;
  ControlIf cIf_pUumfgqw;
  ControlIf cIf_giuFUnjc;
  ControlDelay cDelay_dGX1hzBI;
  ControlBinop cBinop_2PeuS9Ak;
  ControlBinop cBinop_aK3Bi4Db;
  ControlIf cIf_4dyqPBal;
  ControlIf cIf_qrZdNhm9;
  ControlDelay cDelay_b9sB6Wvr;
  ControlBinop cBinop_H9nAKHp4;
  ControlBinop cBinop_NDAdOxRz;
  ControlIf cIf_IuLFcvHe;
  ControlIf cIf_LX6UsjdD;
  ControlDelay cDelay_wjl2CGSw;
  ControlBinop cBinop_sfoXSWPK;
  ControlBinop cBinop_K8yaB7jS;
  ControlIf cIf_YZmdeB4B;
  ControlIf cIf_MJt2r5UR;
  ControlDelay cDelay_p40uQBlT;
  ControlBinop cBinop_Kk9KoNEM;
  ControlBinop cBinop_gyIazyAt;
  ControlIf cIf_7YRG8p0d;
  ControlIf cIf_y5etk4oe;
  ControlDelay cDelay_S5r1va5u;
  ControlBinop cBinop_Kx7l0EiA;
  ControlBinop cBinop_2blo2804;
  ControlIf cIf_K05poGQn;
  ControlIf cIf_nRlQgVqo;
  ControlDelay cDelay_o5T7LAJF;
  ControlBinop cBinop_fikMKrAA;
  ControlBinop cBinop_zpCEHfz7;
  ControlIf cIf_50ycFLMs;
  ControlIf cIf_j1oPLOa4;
  ControlDelay cDelay_JDGE43GF;
  ControlBinop cBinop_iJUfwGsP;
  ControlBinop cBinop_EysYMhZU;
  ControlIf cIf_BV53qg7h;
  ControlIf cIf_fFeOeICo;
  ControlDelay cDelay_BI7jDGIW;
  ControlBinop cBinop_nmhagRob;
  ControlBinop cBinop_FSnKuMfZ;
  ControlIf cIf_UTNoZLsk;
  ControlIf cIf_EemWsL5l;
  ControlDelay cDelay_e80tJhkh;
  ControlBinop cBinop_MoXFiG1n;
  ControlBinop cBinop_i6b1gx1Y;
  ControlIf cIf_xesHqTwE;
  ControlIf cIf_B0MvydKi;
  ControlDelay cDelay_QV2qRSzx;
  ControlBinop cBinop_nj4g7Q9s;
  ControlBinop cBinop_vrraKAPL;
  ControlIf cIf_Y2B4lL0q;
  ControlIf cIf_i6WwzSkI;
  ControlDelay cDelay_1hOVMjtg;
  ControlBinop cBinop_6AkJlPAS;
  ControlBinop cBinop_aFaYrjzb;
  SignalVarf sVarf_DflRtNEn;
  SignalVarf sVarf_CYm8S8jK;
  SignalVarf sVarf_nkemkiYN;
  SignalVarf sVarf_9nLDRCuT;
  SignalVarf sVarf_XTSiRri1;
  SignalVarf sVarf_Yrlc2z5P;
  SignalVarf sVarf_Uhee2Aq0;
  SignalVarf sVarf_YTGM1J0y;
  ControlVar cVar_lP2XrYJV;
  ControlSlice cSlice_hVkJdJqd;
  ControlVar cVar_UdYKh2S1;
  ControlSlice cSlice_eJgTnml8;
  ControlVar cVar_N2e0gyY9;
  ControlSlice cSlice_YuiDO7Wj;
  ControlVar cVar_21FAwV3k;
  ControlSlice cSlice_rnuUbCas;
  ControlVar cVar_Hx3Wvl5Y;
  ControlSlice cSlice_cXCkPcAY;
  ControlVar cVar_CnfQq3nG;
  ControlDelay cDelay_RBcLyU2w;
  ControlVar cVar_2CLBVDxd;
  ControlIf cIf_4anr0KIA;
  ControlIf cIf_J2q37tsN;
  ControlBinop cBinop_iIGGn1Wj;
  ControlBinop cBinop_j1eJnH2O;
  ControlBinop cBinop_KADHKFkT;
  ControlBinop cBinop_yrpdvJ1o;
  ControlBinop cBinop_wK3ZW7i2;
  ControlSlice cSlice_LA3VWI7I;
  ControlVar cVar_cYsHAiuv;
  SignalVarf sVarf_zpiBc2Bb;
  SignalVarf sVarf_UU6FMGPQ;
  SignalVarf sVarf_tP7b94Ti;
  SignalVarf sVarf_m82oJCCs;
  SignalVarf sVarf_6cLlfcLo;
  SignalVarf sVarf_g020HGC0;
  ControlBinop cBinop_7bnmjmpH;
  ControlBinop cBinop_nzdni5ow;
  ControlVar cVar_HMnAlBuC;
  ControlVar cVar_FnuJQHRA;
  ControlIf cIf_JzQGadkP;
  ControlIf cIf_kADh4Sti;
  ControlDelay cDelay_tfj1NevL;
  ControlBinop cBinop_8Pomcwto;
  ControlBinop cBinop_SDcAhrDl;
  ControlIf cIf_iP1GBP3F;
  ControlIf cIf_CTwsqfLD;
  ControlDelay cDelay_uWV8Ykq2;
  ControlBinop cBinop_wdpKLAz6;
  ControlBinop cBinop_HZUL2knp;
  ControlIf cIf_kOWUCxEW;
  ControlIf cIf_01yrIbDk;
  ControlDelay cDelay_SWehebqD;
  ControlBinop cBinop_JTUIITS5;
  ControlBinop cBinop_glTuV18D;
  ControlIf cIf_EIFBqTeK;
  ControlIf cIf_7Gos6AWb;
  ControlDelay cDelay_PlrDjp5r;
  ControlBinop cBinop_1G6smgVu;
  ControlBinop cBinop_Y5kmGigU;
  ControlIf cIf_wyPfNtf8;
  ControlIf cIf_5SVbwh2q;
  ControlDelay cDelay_7rTfuvRR;
  ControlBinop cBinop_rMQvKfVH;
  ControlBinop cBinop_Q6ZOKsUF;
  ControlIf cIf_Cij4FRDB;
  ControlIf cIf_pd4dg6KT;
  ControlDelay cDelay_nx1tJuYo;
  ControlBinop cBinop_etWyGKao;
  ControlBinop cBinop_CeLuwTZv;
  ControlIf cIf_hiuEtWaY;
  ControlIf cIf_3SQgAcGR;
  ControlDelay cDelay_ffcqMVKm;
  ControlBinop cBinop_jbpJN7M0;
  ControlBinop cBinop_qKFEDVZT;
  ControlIf cIf_gqWhXAIH;
  ControlIf cIf_iHBn8rjy;
  ControlDelay cDelay_zcvl9Vi0;
  ControlBinop cBinop_eD2FbFCE;
  ControlBinop cBinop_5WUg4Cpc;
  ControlIf cIf_jHE3H9f3;
  ControlIf cIf_YHH8vyd3;
  ControlDelay cDelay_qkmz6RaC;
  ControlBinop cBinop_2nJdIBkB;
  ControlBinop cBinop_rplHiNMH;
  ControlIf cIf_Qi42PV8y;
  ControlIf cIf_kQGzDWjz;
  ControlDelay cDelay_N5DcpNcF;
  ControlBinop cBinop_ysIkndrV;
  ControlBinop cBinop_zAZChsvj;
  ControlIf cIf_YPIwiWDq;
  ControlIf cIf_fUiwAgbF;
  ControlDelay cDelay_RNKX6ckp;
  ControlBinop cBinop_UDzaoJCE;
  ControlBinop cBinop_08Gt7C9r;
  ControlIf cIf_tAkLA30h;
  ControlIf cIf_RJxrRSkX;
  ControlDelay cDelay_HQMG3m7y;
  ControlBinop cBinop_xO7FBSGT;
  ControlBinop cBinop_GyQMi8Ck;
  SignalVarf sVarf_WTMCRSED;
  SignalVarf sVarf_vl1f6p4D;
  SignalVarf sVarf_j5kPoMkV;
  SignalVarf sVarf_9pGJxgP9;
  SignalVarf sVarf_54FyV2DG;
  SignalVarf sVarf_W4wL8TVd;
  SignalVarf sVarf_9u7Xsd1z;
  SignalVarf sVarf_hD7cnPuL;
  ControlVar cVar_bqjKPRW6;
  ControlSlice cSlice_AQ2bR2zH;
  ControlVar cVar_Jx7A37oC;
  ControlSlice cSlice_O5WcNKU1;
  ControlVar cVar_rmbjTk5E;
  ControlSlice cSlice_P3HLEH9n;
  ControlVar cVar_220V1Jqj;
  ControlSlice cSlice_NEoq435u;
  ControlVar cVar_g5BLJDGn;
  ControlSlice cSlice_VOU2CHCL;
  ControlVar cVar_XvHvUROh;
  ControlDelay cDelay_eSX8jz2e;
  ControlVar cVar_WlxC5ed9;
  ControlIf cIf_zuIYvkys;
  ControlIf cIf_l8oB29G0;
  ControlBinop cBinop_UGMok14j;
  ControlBinop cBinop_8Ro05PIT;
  ControlBinop cBinop_E0E4UOks;
  ControlBinop cBinop_s89ZcETr;
  ControlBinop cBinop_dkt7H96A;
  ControlSlice cSlice_uPURAV4R;
  ControlVar cVar_k6Y8dNux;
  SignalVarf sVarf_bHwBV4fs;
  SignalVarf sVarf_W0lDwF0V;
  SignalVarf sVarf_1V7xYAm5;
  SignalVarf sVarf_HY0DRRJZ;
  SignalVarf sVarf_qV6eVnEH;
  SignalVarf sVarf_eDiuu7Ph;
  ControlBinop cBinop_gvHfpo3B;
  ControlBinop cBinop_hauiRKJw;
  ControlVar cVar_z0YDg9jS;
  SignalVarf sVarf_dUFlVDaW;
  SignalVarf sVarf_Iwd3uIhX;
  SignalVarf sVarf_a4ow5OCS;
  SignalVarf sVarf_cjb2dp9x;
  ControlBinop cBinop_es3X3pCb;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
