/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_q8MkeRKO);
  numBytes += sLine_init(&sLine_otOWOpJ7);
  numBytes += sLine_init(&sLine_XsnCBmlt);
  numBytes += sLine_init(&sLine_xYl5Su7R);
  numBytes += sLine_init(&sLine_aLQuIkHV);
  numBytes += sLine_init(&sLine_M5ttHUpD);
  numBytes += sLine_init(&sLine_bQAebMe3);
  numBytes += sLine_init(&sLine_MqfmrIxs);
  numBytes += sLine_init(&sLine_l0OzIrTy);
  numBytes += sLine_init(&sLine_1IXBNWJd);
  numBytes += sLine_init(&sLine_IPN5JjOz);
  numBytes += sLine_init(&sLine_tHxJObVu);
  numBytes += sEnv_init(&sEnv_R9UclOj1, 512, 256);
  numBytes += sEnv_init(&sEnv_xgqaJSNm, 512, 256);
  numBytes += sLine_init(&sLine_LzW3mqdc);
  numBytes += sLine_init(&sLine_Q0PVSnmY);
  numBytes += sLine_init(&sLine_6AAo6b07);
  numBytes += sLine_init(&sLine_mzjCEywJ);
  numBytes += sLine_init(&sLine_i0nzeinK);
  numBytes += sLine_init(&sLine_BH9kx8YD);
  numBytes += sLine_init(&sLine_bQ0kpNnr);
  numBytes += sLine_init(&sLine_B0pySYnI);
  numBytes += sLine_init(&sLine_Y6ESugOK);
  numBytes += sLine_init(&sLine_EeBrS2vd);
  numBytes += sLine_init(&sLine_5rRzxRcN);
  numBytes += sLine_init(&sLine_qQ7AsD85);
  numBytes += sLine_init(&sLine_QzJkzyZe);
  numBytes += sLine_init(&sLine_bkBl3tvW);
  numBytes += sLine_init(&sLine_WzQRmHWI);
  numBytes += sLine_init(&sLine_EYFosEBW);
  numBytes += sLine_init(&sLine_80XnqXPw);
  numBytes += sLine_init(&sLine_UROws83r);
  numBytes += sEnv_init(&sEnv_ouK9S1KB, 512, 256);
  numBytes += sEnv_init(&sEnv_rotnfrtt, 512, 256);
  numBytes += sLine_init(&sLine_IjH9wthD);
  numBytes += sLine_init(&sLine_pbqNZFGQ);
  numBytes += sLine_init(&sLine_j5S8jlwG);
  numBytes += sLine_init(&sLine_VFSkVAJK);
  numBytes += sLine_init(&sLine_2fDiwNIV);
  numBytes += sLine_init(&sLine_Qi3CztTI);
  numBytes += sLine_init(&sLine_1WnE3hWo);
  numBytes += sLine_init(&sLine_fhTOrb2x);
  numBytes += cVar_init_f(&cVar_CJfbewjo, 0.0f);
  numBytes += cVar_init_f(&cVar_qw1oOd7z, 0.0f);
  numBytes += cVar_init_f(&cVar_Bp12rv1s, 0.0f);
  numBytes += cVar_init_f(&cVar_K3L7cDVs, 0.0f);
  numBytes += cVar_init_f(&cVar_KPE6WbBU, 0.0f);
  numBytes += cVar_init_f(&cVar_ZxGTACkV, 1.0f);
  numBytes += cVar_init_f(&cVar_hP2cPhAb, 0.0f);
  numBytes += cVar_init_f(&cVar_Sew3KMu5, 0.0f);
  numBytes += cIf_init(&cIf_irkEcFyh, false);
  numBytes += cIf_init(&cIf_Djx6E2VE, false);
  numBytes += cDelay_init(this, &cDelay_xCadc2rA, 10.0f);
  numBytes += cIf_init(&cIf_pUumfgqw, false);
  numBytes += cIf_init(&cIf_giuFUnjc, false);
  numBytes += cDelay_init(this, &cDelay_dGX1hzBI, 10.0f);
  numBytes += cIf_init(&cIf_4dyqPBal, false);
  numBytes += cIf_init(&cIf_qrZdNhm9, false);
  numBytes += cDelay_init(this, &cDelay_b9sB6Wvr, 10.0f);
  numBytes += cIf_init(&cIf_IuLFcvHe, false);
  numBytes += cIf_init(&cIf_LX6UsjdD, false);
  numBytes += cDelay_init(this, &cDelay_wjl2CGSw, 10.0f);
  numBytes += cIf_init(&cIf_YZmdeB4B, false);
  numBytes += cIf_init(&cIf_MJt2r5UR, false);
  numBytes += cDelay_init(this, &cDelay_p40uQBlT, 10.0f);
  numBytes += cIf_init(&cIf_7YRG8p0d, false);
  numBytes += cIf_init(&cIf_y5etk4oe, false);
  numBytes += cDelay_init(this, &cDelay_S5r1va5u, 10.0f);
  numBytes += cIf_init(&cIf_K05poGQn, false);
  numBytes += cIf_init(&cIf_nRlQgVqo, false);
  numBytes += cDelay_init(this, &cDelay_o5T7LAJF, 10.0f);
  numBytes += cIf_init(&cIf_50ycFLMs, false);
  numBytes += cIf_init(&cIf_j1oPLOa4, false);
  numBytes += cDelay_init(this, &cDelay_JDGE43GF, 10.0f);
  numBytes += cIf_init(&cIf_BV53qg7h, false);
  numBytes += cIf_init(&cIf_fFeOeICo, false);
  numBytes += cDelay_init(this, &cDelay_BI7jDGIW, 10.0f);
  numBytes += cIf_init(&cIf_UTNoZLsk, false);
  numBytes += cIf_init(&cIf_EemWsL5l, false);
  numBytes += cDelay_init(this, &cDelay_e80tJhkh, 10.0f);
  numBytes += cIf_init(&cIf_xesHqTwE, false);
  numBytes += cIf_init(&cIf_B0MvydKi, false);
  numBytes += cDelay_init(this, &cDelay_QV2qRSzx, 10.0f);
  numBytes += cIf_init(&cIf_Y2B4lL0q, false);
  numBytes += cIf_init(&cIf_i6WwzSkI, false);
  numBytes += cDelay_init(this, &cDelay_1hOVMjtg, 10.0f);
  numBytes += sVarf_init(&sVarf_DflRtNEn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CYm8S8jK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nkemkiYN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9nLDRCuT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XTSiRri1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Yrlc2z5P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Uhee2Aq0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YTGM1J0y, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lP2XrYJV, 0.0f);
  numBytes += cSlice_init(&cSlice_hVkJdJqd, 1, -1);
  numBytes += cVar_init_f(&cVar_UdYKh2S1, 1.0f);
  numBytes += cSlice_init(&cSlice_eJgTnml8, 1, -1);
  numBytes += cVar_init_f(&cVar_N2e0gyY9, 0.0f);
  numBytes += cSlice_init(&cSlice_YuiDO7Wj, 1, -1);
  numBytes += cVar_init_f(&cVar_21FAwV3k, 512.0f);
  numBytes += cSlice_init(&cSlice_rnuUbCas, 1, -1);
  numBytes += cVar_init_f(&cVar_Hx3Wvl5Y, 1.0f);
  numBytes += cSlice_init(&cSlice_cXCkPcAY, 1, -1);
  numBytes += cVar_init_f(&cVar_CnfQq3nG, 1.0f);
  numBytes += cDelay_init(this, &cDelay_RBcLyU2w, 20.0f);
  numBytes += cVar_init_f(&cVar_2CLBVDxd, 0.0f);
  numBytes += cIf_init(&cIf_4anr0KIA, false);
  numBytes += cIf_init(&cIf_J2q37tsN, false);
  numBytes += cBinop_init(&cBinop_iIGGn1Wj, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_LA3VWI7I, 1, -1);
  numBytes += cVar_init_f(&cVar_cYsHAiuv, 0.0f);
  numBytes += sVarf_init(&sVarf_zpiBc2Bb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UU6FMGPQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tP7b94Ti, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m82oJCCs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6cLlfcLo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g020HGC0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HMnAlBuC, 0.0f);
  numBytes += cVar_init_f(&cVar_FnuJQHRA, 0.0f);
  numBytes += cIf_init(&cIf_JzQGadkP, false);
  numBytes += cIf_init(&cIf_kADh4Sti, false);
  numBytes += cDelay_init(this, &cDelay_tfj1NevL, 10.0f);
  numBytes += cIf_init(&cIf_iP1GBP3F, false);
  numBytes += cIf_init(&cIf_CTwsqfLD, false);
  numBytes += cDelay_init(this, &cDelay_uWV8Ykq2, 10.0f);
  numBytes += cIf_init(&cIf_kOWUCxEW, false);
  numBytes += cIf_init(&cIf_01yrIbDk, false);
  numBytes += cDelay_init(this, &cDelay_SWehebqD, 10.0f);
  numBytes += cIf_init(&cIf_EIFBqTeK, false);
  numBytes += cIf_init(&cIf_7Gos6AWb, false);
  numBytes += cDelay_init(this, &cDelay_PlrDjp5r, 10.0f);
  numBytes += cIf_init(&cIf_wyPfNtf8, false);
  numBytes += cIf_init(&cIf_5SVbwh2q, false);
  numBytes += cDelay_init(this, &cDelay_7rTfuvRR, 10.0f);
  numBytes += cIf_init(&cIf_Cij4FRDB, false);
  numBytes += cIf_init(&cIf_pd4dg6KT, false);
  numBytes += cDelay_init(this, &cDelay_nx1tJuYo, 10.0f);
  numBytes += cIf_init(&cIf_hiuEtWaY, false);
  numBytes += cIf_init(&cIf_3SQgAcGR, false);
  numBytes += cDelay_init(this, &cDelay_ffcqMVKm, 10.0f);
  numBytes += cIf_init(&cIf_gqWhXAIH, false);
  numBytes += cIf_init(&cIf_iHBn8rjy, false);
  numBytes += cDelay_init(this, &cDelay_zcvl9Vi0, 10.0f);
  numBytes += cIf_init(&cIf_jHE3H9f3, false);
  numBytes += cIf_init(&cIf_YHH8vyd3, false);
  numBytes += cDelay_init(this, &cDelay_qkmz6RaC, 10.0f);
  numBytes += cIf_init(&cIf_Qi42PV8y, false);
  numBytes += cIf_init(&cIf_kQGzDWjz, false);
  numBytes += cDelay_init(this, &cDelay_N5DcpNcF, 10.0f);
  numBytes += cIf_init(&cIf_YPIwiWDq, false);
  numBytes += cIf_init(&cIf_fUiwAgbF, false);
  numBytes += cDelay_init(this, &cDelay_RNKX6ckp, 10.0f);
  numBytes += cIf_init(&cIf_tAkLA30h, false);
  numBytes += cIf_init(&cIf_RJxrRSkX, false);
  numBytes += cDelay_init(this, &cDelay_HQMG3m7y, 10.0f);
  numBytes += sVarf_init(&sVarf_WTMCRSED, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vl1f6p4D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j5kPoMkV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9pGJxgP9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_54FyV2DG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W4wL8TVd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9u7Xsd1z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hD7cnPuL, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bqjKPRW6, 0.0f);
  numBytes += cSlice_init(&cSlice_AQ2bR2zH, 1, -1);
  numBytes += cVar_init_f(&cVar_Jx7A37oC, 1.0f);
  numBytes += cSlice_init(&cSlice_O5WcNKU1, 1, -1);
  numBytes += cVar_init_f(&cVar_rmbjTk5E, 0.0f);
  numBytes += cSlice_init(&cSlice_P3HLEH9n, 1, -1);
  numBytes += cVar_init_f(&cVar_220V1Jqj, 512.0f);
  numBytes += cSlice_init(&cSlice_NEoq435u, 1, -1);
  numBytes += cVar_init_f(&cVar_g5BLJDGn, 1.0f);
  numBytes += cSlice_init(&cSlice_VOU2CHCL, 1, -1);
  numBytes += cVar_init_f(&cVar_XvHvUROh, 1.0f);
  numBytes += cDelay_init(this, &cDelay_eSX8jz2e, 20.0f);
  numBytes += cVar_init_f(&cVar_WlxC5ed9, 0.0f);
  numBytes += cIf_init(&cIf_zuIYvkys, false);
  numBytes += cIf_init(&cIf_l8oB29G0, false);
  numBytes += cBinop_init(&cBinop_UGMok14j, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_uPURAV4R, 1, -1);
  numBytes += cVar_init_f(&cVar_k6Y8dNux, 0.0f);
  numBytes += sVarf_init(&sVarf_bHwBV4fs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W0lDwF0V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1V7xYAm5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HY0DRRJZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qV6eVnEH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eDiuu7Ph, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_z0YDg9jS, 0.0f);
  numBytes += sVarf_init(&sVarf_dUFlVDaW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Iwd3uIhX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a4ow5OCS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cjb2dp9x, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_R9UclOj1);
  sEnv_free(&sEnv_xgqaJSNm);
  sEnv_free(&sEnv_ouK9S1KB);
  sEnv_free(&sEnv_rotnfrtt);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VpYjGlCP_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6KQH6Ilx_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tKopam3f_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GjHBESxq_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JMDq8a2j_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zJ9c7FPs_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tRwnpZbj_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HUTQCdhU_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EddwNtx7_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lCdH0NQT_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yaMSJyND_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aOq7EAxj_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2xW5sHXJ_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F2zboOao_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fs73XspK_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_L3khMqsC_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pu57HRiY_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ur2Rh5Jr_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7DWzgcpA_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3oT5hjM7_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y38LknwK_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_CJfbewjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S5pAySuZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_Bhgo4rlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_P1xryvde_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_P1xryvde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TYYfV0g9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TYYfV0g9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SSJIXKAs_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_SSJIXKAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PBJV9Jjz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cpp1cYvX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PBJV9Jjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BZGpjnch_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Cpp1cYvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hBPzmuj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_BZGpjnch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sWdbvfJB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hBPzmuj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iZJLr9Bh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iZJLr9Bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ad4g4tD5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sWdbvfJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aHEujlDl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_Ad4g4tD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCniOfpc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_qw1oOd7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b9eYlJRV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_Bp12rv1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7lJH6zmt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_K3L7cDVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ncQDjVor_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_KPE6WbBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RER5qTVD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_ZxGTACkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6eSMoMui_sendMessage);
  cMsg_sRPV4efD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_6eSMoMui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZxGTACkV, 1, m, &cVar_ZxGTACkV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_urDVnMk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PvSvbmbo_sendMessage(_c, 0, m);
  cMsg_ovuXDhRb_sendMessage(_c, 0, m);
  cMsg_ufaOmK46_sendMessage(_c, 0, m);
  cMsg_PavbT31b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_hP2cPhAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dEUKWGrE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_Sew3KMu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HYJkjZwx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_e3TZAFXD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TyFVOS3Z_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fgJeaEv3_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YqxISkPP_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O31nWhTQ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Rpp6UmL_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6IJ3vl1I_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_TyFVOS3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jH63nkr0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_fgJeaEv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iTiUUqF7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_YqxISkPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aLsI4I4f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_O31nWhTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sDxXajsJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_8Rpp6UmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5nDq21mO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_6IJ3vl1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5NrQMh6U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_irkEcFyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_N8Ft7lbo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Djx6E2VE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MQhQihwh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_pp4jpsm7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8A0DEZhn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8A0DEZhn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xCadc2rA, 1, m, &cDelay_xCadc2rA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VOmiQiCY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_xCadc2rA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xCadc2rA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_irkEcFyh, 0, m, &cIf_irkEcFyh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8A0DEZhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xCadc2rA, 0, m, &cDelay_xCadc2rA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VOmiQiCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xCadc2rA, 0, m, &cDelay_xCadc2rA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_SXj758vo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2S72RUAN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d6fJ2vIg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Jb7daM3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8xweh5zJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_reDI3qtc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_reDI3qtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pp4jpsm7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_8xweh5zJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_irkEcFyh, 1, m, &cIf_irkEcFyh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2S72RUAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Djx6E2VE, 1, m, &cIf_Djx6E2VE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_d6fJ2vIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Djx6E2VE, 0, m, &cIf_Djx6E2VE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MQhQihwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xYl5Su7R, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_N8Ft7lbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xYl5Su7R, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_pUumfgqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jIg6ePBv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_giuFUnjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SOeoeAkf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_YKKZ7fPp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_A0CdaP09_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_A0CdaP09_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dGX1hzBI, 1, m, &cDelay_dGX1hzBI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u0WXRQLW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_dGX1hzBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dGX1hzBI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pUumfgqw, 0, m, &cIf_pUumfgqw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_A0CdaP09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dGX1hzBI, 0, m, &cDelay_dGX1hzBI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_u0WXRQLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dGX1hzBI, 0, m, &cDelay_dGX1hzBI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2PeuS9Ak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bnVxAkP6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iHMoLy8z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aK3Bi4Db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uFQ5Idtz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mgDxdtlb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mgDxdtlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YKKZ7fPp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_uFQ5Idtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pUumfgqw, 1, m, &cIf_pUumfgqw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bnVxAkP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_giuFUnjc, 1, m, &cIf_giuFUnjc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iHMoLy8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_giuFUnjc, 0, m, &cIf_giuFUnjc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SOeoeAkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bQAebMe3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jIg6ePBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bQAebMe3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_4dyqPBal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WA5MYRYW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_qrZdNhm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1UWjtgma_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_7CoNZ39N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EMupfa2K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EMupfa2K_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_b9sB6Wvr, 1, m, &cDelay_b9sB6Wvr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YIMK6wcC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_b9sB6Wvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b9sB6Wvr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4dyqPBal, 0, m, &cIf_4dyqPBal_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EMupfa2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b9sB6Wvr, 0, m, &cDelay_b9sB6Wvr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YIMK6wcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b9sB6Wvr, 0, m, &cDelay_b9sB6Wvr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_H9nAKHp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJl3iitP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jHHduX9a_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NDAdOxRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UUKbuYSo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z2Qi2pnv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UUKbuYSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4dyqPBal, 1, m, &cIf_4dyqPBal_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Z2Qi2pnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7CoNZ39N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_VJl3iitP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qrZdNhm9, 1, m, &cIf_qrZdNhm9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jHHduX9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qrZdNhm9, 0, m, &cIf_qrZdNhm9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1UWjtgma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1IXBNWJd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_WA5MYRYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1IXBNWJd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_IuLFcvHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ExQDfTRf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_LX6UsjdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FlK4jegf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_jLpamAz9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wUqr38w8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wUqr38w8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wjl2CGSw, 1, m, &cDelay_wjl2CGSw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LGWfqdL0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wjl2CGSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wjl2CGSw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IuLFcvHe, 0, m, &cIf_IuLFcvHe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wUqr38w8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wjl2CGSw, 0, m, &cDelay_wjl2CGSw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LGWfqdL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wjl2CGSw, 0, m, &cDelay_wjl2CGSw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sfoXSWPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UjxkVVME_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sxCBdWJ9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_K8yaB7jS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lC6hSIQS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9p5W2y5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9p5W2y5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jLpamAz9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_lC6hSIQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IuLFcvHe, 1, m, &cIf_IuLFcvHe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sxCBdWJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LX6UsjdD, 0, m, &cIf_LX6UsjdD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UjxkVVME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LX6UsjdD, 1, m, &cIf_LX6UsjdD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FlK4jegf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aLQuIkHV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ExQDfTRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aLQuIkHV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_YZmdeB4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eamLSx3v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_MJt2r5UR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VktrF4AH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_pYbtVQzA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uNcqS8pk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uNcqS8pk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p40uQBlT, 1, m, &cDelay_p40uQBlT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t04Am45Y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_p40uQBlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p40uQBlT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YZmdeB4B, 0, m, &cIf_YZmdeB4B_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uNcqS8pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p40uQBlT, 0, m, &cDelay_p40uQBlT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_t04Am45Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p40uQBlT, 0, m, &cDelay_p40uQBlT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Kk9KoNEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RFpkOeP1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XKtVEWbc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gyIazyAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DYU5yjXq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LQahEAcQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DYU5yjXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YZmdeB4B, 1, m, &cIf_YZmdeB4B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LQahEAcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pYbtVQzA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_RFpkOeP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MJt2r5UR, 1, m, &cIf_MJt2r5UR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XKtVEWbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MJt2r5UR, 0, m, &cIf_MJt2r5UR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VktrF4AH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MqfmrIxs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_eamLSx3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MqfmrIxs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_7YRG8p0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r7qOvP7U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_y5etk4oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_M6KxKonD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5B1r3JvB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Gxp2lLyb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Gxp2lLyb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_S5r1va5u, 1, m, &cDelay_S5r1va5u_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mu9Xwmv0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_S5r1va5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S5r1va5u, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7YRG8p0d, 0, m, &cIf_7YRG8p0d_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Gxp2lLyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_S5r1va5u, 0, m, &cDelay_S5r1va5u_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Mu9Xwmv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_S5r1va5u, 0, m, &cDelay_S5r1va5u_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Kx7l0EiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_diKLAlMr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YRfGgO13_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2blo2804_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YTumkDXX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pG3waefX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pG3waefX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5B1r3JvB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YTumkDXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7YRG8p0d, 1, m, &cIf_7YRG8p0d_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_diKLAlMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y5etk4oe, 1, m, &cIf_y5etk4oe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YRfGgO13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y5etk4oe, 0, m, &cIf_y5etk4oe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_M6KxKonD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IPN5JjOz, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_r7qOvP7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IPN5JjOz, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_K05poGQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nda98IAc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nRlQgVqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Fsr4PrMs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_wRKcFL3F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uHcvGNon_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uHcvGNon_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_o5T7LAJF, 1, m, &cDelay_o5T7LAJF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lgzfVKpE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_o5T7LAJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_o5T7LAJF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_K05poGQn, 0, m, &cIf_K05poGQn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uHcvGNon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_o5T7LAJF, 0, m, &cDelay_o5T7LAJF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lgzfVKpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_o5T7LAJF, 0, m, &cDelay_o5T7LAJF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fikMKrAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8uPX1OMr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EPGQf6KM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_zpCEHfz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6BFpwvd7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q946YAog_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_q946YAog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wRKcFL3F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_6BFpwvd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K05poGQn, 1, m, &cIf_K05poGQn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EPGQf6KM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nRlQgVqo, 0, m, &cIf_nRlQgVqo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8uPX1OMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nRlQgVqo, 1, m, &cIf_nRlQgVqo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Fsr4PrMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M5ttHUpD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Nda98IAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M5ttHUpD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_50ycFLMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_myt3laoD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_j1oPLOa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4MT52PME_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_pRCdgkX8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WkfBwyoK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WkfBwyoK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JDGE43GF, 1, m, &cDelay_JDGE43GF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NeXXRCKB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_JDGE43GF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JDGE43GF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_50ycFLMs, 0, m, &cIf_50ycFLMs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WkfBwyoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JDGE43GF, 0, m, &cDelay_JDGE43GF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NeXXRCKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JDGE43GF, 0, m, &cDelay_JDGE43GF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iJUfwGsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fXrDVuN9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i5bVq0AT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EysYMhZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BGSRe7ei_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NEbc2cyQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_BGSRe7ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_50ycFLMs, 1, m, &cIf_50ycFLMs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NEbc2cyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pRCdgkX8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_fXrDVuN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j1oPLOa4, 1, m, &cIf_j1oPLOa4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_i5bVq0AT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j1oPLOa4, 0, m, &cIf_j1oPLOa4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4MT52PME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l0OzIrTy, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_myt3laoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l0OzIrTy, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_BV53qg7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oT41aAUJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_fFeOeICo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1MdeqFib_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_h5qSOe1j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KmpiAgmt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KmpiAgmt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BI7jDGIW, 1, m, &cDelay_BI7jDGIW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WuRyxTal_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_BI7jDGIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BI7jDGIW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BV53qg7h, 0, m, &cIf_BV53qg7h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KmpiAgmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BI7jDGIW, 0, m, &cDelay_BI7jDGIW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WuRyxTal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BI7jDGIW, 0, m, &cDelay_BI7jDGIW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nmhagRob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ui0ommLY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EBW7AJCr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FSnKuMfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QcjdzoEt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8mLMHG6J_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8mLMHG6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_h5qSOe1j_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_QcjdzoEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BV53qg7h, 1, m, &cIf_BV53qg7h_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EBW7AJCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fFeOeICo, 0, m, &cIf_fFeOeICo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ui0ommLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fFeOeICo, 1, m, &cIf_fFeOeICo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1MdeqFib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tHxJObVu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_oT41aAUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tHxJObVu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_UTNoZLsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LbSc52Md_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_EemWsL5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UfI38h2Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_wCr1XH9X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8npa41Vh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8npa41Vh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_e80tJhkh, 1, m, &cDelay_e80tJhkh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_14y6ZQLt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_e80tJhkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e80tJhkh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UTNoZLsk, 0, m, &cIf_UTNoZLsk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8npa41Vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_e80tJhkh, 0, m, &cDelay_e80tJhkh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_14y6ZQLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_e80tJhkh, 0, m, &cDelay_e80tJhkh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MoXFiG1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WuPbVIiw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2L5ksgTA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_i6b1gx1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XdbbDuju_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r1MUFb8W_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_r1MUFb8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wCr1XH9X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_XdbbDuju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UTNoZLsk, 1, m, &cIf_UTNoZLsk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2L5ksgTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EemWsL5l, 0, m, &cIf_EemWsL5l_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WuPbVIiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EemWsL5l, 1, m, &cIf_EemWsL5l_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UfI38h2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8MkeRKO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LbSc52Md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8MkeRKO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xesHqTwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_X0hG1Ri4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_B0MvydKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8wednO6Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Pge9XQ9c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lUuBcvn8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lUuBcvn8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QV2qRSzx, 1, m, &cDelay_QV2qRSzx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VxBs7IDQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_QV2qRSzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QV2qRSzx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xesHqTwE, 0, m, &cIf_xesHqTwE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lUuBcvn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QV2qRSzx, 0, m, &cDelay_QV2qRSzx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VxBs7IDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QV2qRSzx, 0, m, &cDelay_QV2qRSzx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nj4g7Q9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C4SPpCw3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uYjXETN6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_vrraKAPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CgTO8ySP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g9V3SHfO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CgTO8ySP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xesHqTwE, 1, m, &cIf_xesHqTwE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_g9V3SHfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Pge9XQ9c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_uYjXETN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B0MvydKi, 0, m, &cIf_B0MvydKi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C4SPpCw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B0MvydKi, 1, m, &cIf_B0MvydKi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8wednO6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_otOWOpJ7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_X0hG1Ri4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_otOWOpJ7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Y2B4lL0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PaGUoMVt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_i6WwzSkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dIBrBFOc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_IwpsywY6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_P1c7vA7S_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_P1c7vA7S_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1hOVMjtg, 1, m, &cDelay_1hOVMjtg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v0xt4Lkm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_1hOVMjtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1hOVMjtg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y2B4lL0q, 0, m, &cIf_Y2B4lL0q_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P1c7vA7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1hOVMjtg, 0, m, &cDelay_1hOVMjtg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_v0xt4Lkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1hOVMjtg, 0, m, &cDelay_1hOVMjtg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6AkJlPAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pKFhaLp8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aVYcg9ih_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aFaYrjzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HtxMHdwi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oFTIpofi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oFTIpofi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IwpsywY6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_HtxMHdwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y2B4lL0q, 1, m, &cIf_Y2B4lL0q_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aVYcg9ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i6WwzSkI, 0, m, &cIf_i6WwzSkI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pKFhaLp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i6WwzSkI, 1, m, &cIf_i6WwzSkI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dIBrBFOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XsnCBmlt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_PaGUoMVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XsnCBmlt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jH63nkr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_D3NjIgim_sendMessage(_c, 0, m);
  cMsg_H0xYCr62_sendMessage(_c, 0, m);
  cMsg_GYtgHz8V_sendMessage(_c, 0, m);
  cMsg_fSw8uuVH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_iTiUUqF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_D3NjIgim_sendMessage(_c, 0, m);
  cMsg_MuIHMCSK_sendMessage(_c, 0, m);
  cMsg_eOcSwJc2_sendMessage(_c, 0, m);
  cMsg_WvvEKdM2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aLsI4I4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_zw3Cixhw_sendMessage(_c, 0, m);
  cMsg_MuIHMCSK_sendMessage(_c, 0, m);
  cMsg_fSw8uuVH_sendMessage(_c, 0, m);
  cMsg_KWwUqXHH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sDxXajsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_zw3Cixhw_sendMessage(_c, 0, m);
  cMsg_PG1Fj7Xw_sendMessage(_c, 0, m);
  cMsg_GYtgHz8V_sendMessage(_c, 0, m);
  cMsg_PLoWGokC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5nDq21mO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_9NAX0jOi_sendMessage(_c, 0, m);
  cMsg_WvvEKdM2_sendMessage(_c, 0, m);
  cMsg_9ltt4MLM_sendMessage(_c, 0, m);
  cMsg_GYtgHz8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5NrQMh6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_9NAX0jOi_sendMessage(_c, 0, m);
  cMsg_PLoWGokC_sendMessage(_c, 0, m);
  cMsg_MuIHMCSK_sendMessage(_c, 0, m);
  cMsg_ZaI4N2Ul_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_NdAxZ4WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Jb7daM3U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SXj758vo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DmX8xaFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Jb7daM3U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SXj758vo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9D7uxIwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aK3Bi4Db_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2PeuS9Ak_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_srSiTiw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aK3Bi4Db_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2PeuS9Ak_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YoA4mexV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NDAdOxRz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H9nAKHp4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3XQfzO6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NDAdOxRz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H9nAKHp4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_D3NjIgim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_NdAxZ4WT_sendMessage(_c, 0, m);
  cMsg_srSiTiw0_sendMessage(_c, 0, m);
  cMsg_3XQfzO6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zw3Cixhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_DmX8xaFm_sendMessage(_c, 0, m);
  cMsg_9D7uxIwX_sendMessage(_c, 0, m);
  cMsg_3XQfzO6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9NAX0jOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_DmX8xaFm_sendMessage(_c, 0, m);
  cMsg_srSiTiw0_sendMessage(_c, 0, m);
  cMsg_YoA4mexV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Js27SZfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K8yaB7jS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sfoXSWPK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nYuR3Djq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K8yaB7jS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sfoXSWPK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HSNaaw0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gyIazyAt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kk9KoNEM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cmcofGY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gyIazyAt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kk9KoNEM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_l1xzOMem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2blo2804_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kx7l0EiA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HRuwCEEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2blo2804_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kx7l0EiA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MuIHMCSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_nYuR3Djq_sendMessage(_c, 0, m);
  cMsg_cmcofGY4_sendMessage(_c, 0, m);
  cMsg_HRuwCEEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_H0xYCr62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_nYuR3Djq_sendMessage(_c, 0, m);
  cMsg_HSNaaw0d_sendMessage(_c, 0, m);
  cMsg_l1xzOMem_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_PG1Fj7Xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Js27SZfB_sendMessage(_c, 0, m);
  cMsg_cmcofGY4_sendMessage(_c, 0, m);
  cMsg_l1xzOMem_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oorqvb6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i6b1gx1Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MoXFiG1n_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vbedpvhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i6b1gx1Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MoXFiG1n_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5FAKKCgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vrraKAPL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nj4g7Q9s_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P18NX9B5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vrraKAPL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nj4g7Q9s_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aNPboW80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aFaYrjzb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6AkJlPAS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wtVIQw5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aFaYrjzb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6AkJlPAS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PLoWGokC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_oorqvb6P_sendMessage(_c, 0, m);
  cMsg_P18NX9B5_sendMessage(_c, 0, m);
  cMsg_wtVIQw5Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WvvEKdM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_vbedpvhW_sendMessage(_c, 0, m);
  cMsg_5FAKKCgV_sendMessage(_c, 0, m);
  cMsg_wtVIQw5Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fSw8uuVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_vbedpvhW_sendMessage(_c, 0, m);
  cMsg_P18NX9B5_sendMessage(_c, 0, m);
  cMsg_aNPboW80_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bKPCfqTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zpCEHfz7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fikMKrAA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_faA1hC8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zpCEHfz7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fikMKrAA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zxrDve35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EysYMhZU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iJUfwGsP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rlopynJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EysYMhZU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iJUfwGsP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_44RqSbgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FSnKuMfZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nmhagRob_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0s5aNX5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FSnKuMfZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nmhagRob_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GYtgHz8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_faA1hC8h_sendMessage(_c, 0, m);
  cMsg_rlopynJF_sendMessage(_c, 0, m);
  cMsg_0s5aNX5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eOcSwJc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_faA1hC8h_sendMessage(_c, 0, m);
  cMsg_zxrDve35_sendMessage(_c, 0, m);
  cMsg_44RqSbgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZaI4N2Ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_bKPCfqTh_sendMessage(_c, 0, m);
  cMsg_zxrDve35_sendMessage(_c, 0, m);
  cMsg_0s5aNX5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9ltt4MLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Js27SZfB_sendMessage(_c, 0, m);
  cMsg_HSNaaw0d_sendMessage(_c, 0, m);
  cMsg_HRuwCEEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KWwUqXHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_bKPCfqTh_sendMessage(_c, 0, m);
  cMsg_rlopynJF_sendMessage(_c, 0, m);
  cMsg_44RqSbgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_lP2XrYJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tgsVKD6Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_o6TLV7Lf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hVkJdJqd, 0, m, &cSlice_hVkJdJqd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2QhIGi31_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_hVkJdJqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xro9oqlu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xro9oqlu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_UdYKh2S1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xro9oqlu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_xro9oqlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lCdH0NQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_R4KhDNRS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eJgTnml8, 0, m, &cSlice_eJgTnml8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UJ2DsykM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_eJgTnml8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BNna4SJh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BNna4SJh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_N2e0gyY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BNna4SJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_BNna4SJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F2zboOao_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_UJ2DsykM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YuiDO7Wj, 0, m, &cSlice_YuiDO7Wj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_o6TLV7Lf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_YuiDO7Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AijXjQXP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AijXjQXP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_21FAwV3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AijXjQXP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_AijXjQXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EddwNtx7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_2QhIGi31_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rnuUbCas, 0, m, &cSlice_rnuUbCas_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XGcKKeaz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_rnuUbCas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_v1HoiZpH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_v1HoiZpH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_Hx3Wvl5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v1HoiZpH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_v1HoiZpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2xW5sHXJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_XGcKKeaz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cXCkPcAY, 0, m, &cSlice_cXCkPcAY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_L1pIL8qo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_cXCkPcAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wgLitw1n_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wgLitw1n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_CnfQq3nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wgLitw1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_wgLitw1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aOq7EAxj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_GFqd6FJG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ttbka1MP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ttbka1MP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RBcLyU2w, 1, m, &cDelay_RBcLyU2w_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QM6OL9xb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_RBcLyU2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RBcLyU2w, m);
  cMsg_wpugiIKM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ttbka1MP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RBcLyU2w, 0, m, &cDelay_RBcLyU2w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QM6OL9xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RBcLyU2w, 0, m, &cDelay_RBcLyU2w_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_2CLBVDxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIGGn1Wj, HV_BINOP_SUBTRACT, 0, m, &cBinop_iIGGn1Wj_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_4anr0KIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rzHEJScw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_J2q37tsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rzHEJScw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_R9UclOj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2CLBVDxd, 0, m, &cVar_2CLBVDxd_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_xgqaJSNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KmGdDsAj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lSXtDgSk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C51Fr1Dx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iIGGn1Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9XcQoZr4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9XcQoZr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_j1eJnH2O_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_j1eJnH2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wK3ZW7i2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KADHKFkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_syI7KuAv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YlIN8gq8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YlIN8gq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fcacVDeD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_syI7KuAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4anr0KIA, 1, m, &cIf_4anr0KIA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yrpdvJ1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J2q37tsN, 1, m, &cIf_J2q37tsN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fcacVDeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4anr0KIA, 0, m, &cIf_4anr0KIA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wK3ZW7i2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J2q37tsN, 0, m, &cIf_J2q37tsN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lSXtDgSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIGGn1Wj, HV_BINOP_SUBTRACT, 1, m, &cBinop_iIGGn1Wj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C51Fr1Dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2CLBVDxd, 0, m, &cVar_2CLBVDxd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KmGdDsAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cMsg_rzHEJScw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LzW3mqdc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_L1pIL8qo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LA3VWI7I, 0, m, &cSlice_LA3VWI7I_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_LA3VWI7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ocl2XZ8f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ocl2XZ8f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_cYsHAiuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ocl2XZ8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Ocl2XZ8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yaMSJyND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dEUKWGrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BH9kx8YD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HYJkjZwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mzjCEywJ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_7bnmjmpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sew3KMu5, 0, m, &cVar_Sew3KMu5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tgsVKD6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i0nzeinK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_I2dV3F2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vOkUulgW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_AZb2Ioax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GFqd6FJG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wpugiIKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q0PVSnmY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vOkUulgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q0PVSnmY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xlCVP3QY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_nzdni5ow_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nzdni5ow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f84Beymj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_f84Beymj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6AAo6b07, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_HMnAlBuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJwfOaTS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_FnuJQHRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HZ7FFh8l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_CckwPojq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tE787RUG_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_piWXMc5G_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NKrzeAEH_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XhMWIFrp_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O6TEEsd8_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VNnc5QVM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_tE787RUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KSGnFGrx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_piWXMc5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OTuFklVv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_NKrzeAEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MF4NSLVl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_XhMWIFrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BsYFAULd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_O6TEEsd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hwy7osvG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_VNnc5QVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d4P1rBOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_JzQGadkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7QJEBas7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_kADh4Sti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_77HiJ0dB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_mg8mh2dJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rujg9HNB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rujg9HNB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tfj1NevL, 1, m, &cDelay_tfj1NevL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pTuUrGHx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_tfj1NevL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tfj1NevL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JzQGadkP, 0, m, &cIf_JzQGadkP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rujg9HNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tfj1NevL, 0, m, &cDelay_tfj1NevL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pTuUrGHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tfj1NevL, 0, m, &cDelay_tfj1NevL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8Pomcwto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DNlmPTIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_57n5jYiL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_SDcAhrDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rFVRTjlN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WlpLqk5s_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WlpLqk5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mg8mh2dJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_rFVRTjlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JzQGadkP, 1, m, &cIf_JzQGadkP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DNlmPTIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kADh4Sti, 1, m, &cIf_kADh4Sti_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_57n5jYiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kADh4Sti, 0, m, &cIf_kADh4Sti_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_77HiJ0dB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EeBrS2vd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7QJEBas7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EeBrS2vd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_iP1GBP3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2TwyDQE8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_CTwsqfLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UjuAwxxU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bdVz0LhV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZSjk7Bqd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZSjk7Bqd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uWV8Ykq2, 1, m, &cDelay_uWV8Ykq2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rW04Bnr1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_uWV8Ykq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uWV8Ykq2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iP1GBP3F, 0, m, &cIf_iP1GBP3F_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZSjk7Bqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uWV8Ykq2, 0, m, &cDelay_uWV8Ykq2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rW04Bnr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uWV8Ykq2, 0, m, &cDelay_uWV8Ykq2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wdpKLAz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6RpUyueH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SoYe5plY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HZUL2knp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EeXF9tyD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TgatKY35_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TgatKY35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bdVz0LhV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_EeXF9tyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iP1GBP3F, 1, m, &cIf_iP1GBP3F_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SoYe5plY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CTwsqfLD, 0, m, &cIf_CTwsqfLD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6RpUyueH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CTwsqfLD, 1, m, &cIf_CTwsqfLD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UjuAwxxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QzJkzyZe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2TwyDQE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QzJkzyZe, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_kOWUCxEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vYZ97wuK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_01yrIbDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4Xyog3Fa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_dSlWkijD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zLEuwJZn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zLEuwJZn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SWehebqD, 1, m, &cDelay_SWehebqD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TALVJEzl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_SWehebqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SWehebqD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kOWUCxEW, 0, m, &cIf_kOWUCxEW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zLEuwJZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SWehebqD, 0, m, &cDelay_SWehebqD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TALVJEzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SWehebqD, 0, m, &cDelay_SWehebqD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JTUIITS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9aW42u7W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aktELYm9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_glTuV18D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QmO3zEdk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZgNDgNr9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZgNDgNr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dSlWkijD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_QmO3zEdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kOWUCxEW, 1, m, &cIf_kOWUCxEW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aktELYm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_01yrIbDk, 0, m, &cIf_01yrIbDk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9aW42u7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_01yrIbDk, 1, m, &cIf_01yrIbDk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4Xyog3Fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EYFosEBW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vYZ97wuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EYFosEBW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_EIFBqTeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4Ii8cJ0x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7Gos6AWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rTWfet5T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_J1hpNM08_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3i3sRcxf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3i3sRcxf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PlrDjp5r, 1, m, &cDelay_PlrDjp5r_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WBwvxWuv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_PlrDjp5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PlrDjp5r, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EIFBqTeK, 0, m, &cIf_EIFBqTeK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3i3sRcxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PlrDjp5r, 0, m, &cDelay_PlrDjp5r_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WBwvxWuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PlrDjp5r, 0, m, &cDelay_PlrDjp5r_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1G6smgVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sw8U10G2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_edrJfmvn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Y5kmGigU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zpHGcFJX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rkDlijiJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rkDlijiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J1hpNM08_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zpHGcFJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EIFBqTeK, 1, m, &cIf_EIFBqTeK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_edrJfmvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Gos6AWb, 0, m, &cIf_7Gos6AWb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sw8U10G2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Gos6AWb, 1, m, &cIf_7Gos6AWb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rTWfet5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5rRzxRcN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4Ii8cJ0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5rRzxRcN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_wyPfNtf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dFqS4Ppc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_5SVbwh2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Qm9cD5jD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_l1yjxHcw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BnrmPY6J_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BnrmPY6J_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7rTfuvRR, 1, m, &cDelay_7rTfuvRR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KzPzKmvs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7rTfuvRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7rTfuvRR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wyPfNtf8, 0, m, &cIf_wyPfNtf8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BnrmPY6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7rTfuvRR, 0, m, &cDelay_7rTfuvRR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KzPzKmvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7rTfuvRR, 0, m, &cDelay_7rTfuvRR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rMQvKfVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4mQDpwXZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ANeW4sfv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Q6ZOKsUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_einDfqyn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7MC0k2vs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_einDfqyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wyPfNtf8, 1, m, &cIf_wyPfNtf8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7MC0k2vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_l1yjxHcw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_4mQDpwXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5SVbwh2q, 1, m, &cIf_5SVbwh2q_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ANeW4sfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5SVbwh2q, 0, m, &cIf_5SVbwh2q_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Qm9cD5jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bkBl3tvW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_dFqS4Ppc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bkBl3tvW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Cij4FRDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_x7dgEFSm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_pd4dg6KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SCOxU634_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_lBG0AsOT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jjylMrvn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jjylMrvn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nx1tJuYo, 1, m, &cDelay_nx1tJuYo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5H8OSF2T_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_nx1tJuYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nx1tJuYo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Cij4FRDB, 0, m, &cIf_Cij4FRDB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jjylMrvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nx1tJuYo, 0, m, &cDelay_nx1tJuYo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5H8OSF2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nx1tJuYo, 0, m, &cDelay_nx1tJuYo_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_etWyGKao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1VVPF4cX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pJ5KrLas_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CeLuwTZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lCIk3zrn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D4GD9dkc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_D4GD9dkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lBG0AsOT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_lCIk3zrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cij4FRDB, 1, m, &cIf_Cij4FRDB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pJ5KrLas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pd4dg6KT, 0, m, &cIf_pd4dg6KT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1VVPF4cX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pd4dg6KT, 1, m, &cIf_pd4dg6KT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SCOxU634_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_80XnqXPw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_x7dgEFSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_80XnqXPw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_hiuEtWaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_n3tH8Ils_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_3SQgAcGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LbBLTDHK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_al0i5JNH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7HK1CM49_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7HK1CM49_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ffcqMVKm, 1, m, &cDelay_ffcqMVKm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ybl2zow2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ffcqMVKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ffcqMVKm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hiuEtWaY, 0, m, &cIf_hiuEtWaY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7HK1CM49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ffcqMVKm, 0, m, &cDelay_ffcqMVKm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ybl2zow2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ffcqMVKm, 0, m, &cDelay_ffcqMVKm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jbpJN7M0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DwuGPsdo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zAiQCaQJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qKFEDVZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OOTf9391_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1fqAnVSc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1fqAnVSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_al0i5JNH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OOTf9391_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hiuEtWaY, 1, m, &cIf_hiuEtWaY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zAiQCaQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3SQgAcGR, 0, m, &cIf_3SQgAcGR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DwuGPsdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3SQgAcGR, 1, m, &cIf_3SQgAcGR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LbBLTDHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qQ7AsD85, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_n3tH8Ils_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qQ7AsD85, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_gqWhXAIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XyrRZx0J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_iHBn8rjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g5KzRXKH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_jrz0YuR1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_j95obQ1F_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_j95obQ1F_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zcvl9Vi0, 1, m, &cDelay_zcvl9Vi0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gUkLQuv1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_zcvl9Vi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zcvl9Vi0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gqWhXAIH, 0, m, &cIf_gqWhXAIH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_j95obQ1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zcvl9Vi0, 0, m, &cDelay_zcvl9Vi0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gUkLQuv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zcvl9Vi0, 0, m, &cDelay_zcvl9Vi0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eD2FbFCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kvfEknPm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dhSpKSCa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5WUg4Cpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0S1bGVOj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hdBzrGh4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hdBzrGh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jrz0YuR1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_0S1bGVOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gqWhXAIH, 1, m, &cIf_gqWhXAIH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kvfEknPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iHBn8rjy, 1, m, &cIf_iHBn8rjy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dhSpKSCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iHBn8rjy, 0, m, &cIf_iHBn8rjy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_g5KzRXKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WzQRmHWI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XyrRZx0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WzQRmHWI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_jHE3H9f3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_supEZNyA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_YHH8vyd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PLB5CFlX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_aeV6Q5e6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wHyQXbZi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wHyQXbZi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qkmz6RaC, 1, m, &cDelay_qkmz6RaC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SgPnomqz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_qkmz6RaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qkmz6RaC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jHE3H9f3, 0, m, &cIf_jHE3H9f3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wHyQXbZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qkmz6RaC, 0, m, &cDelay_qkmz6RaC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SgPnomqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qkmz6RaC, 0, m, &cDelay_qkmz6RaC_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2nJdIBkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NBRePqwE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gCgN5CtJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rplHiNMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L3PKnwHE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EEeHLW2I_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EEeHLW2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aeV6Q5e6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_L3PKnwHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHE3H9f3, 1, m, &cIf_jHE3H9f3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gCgN5CtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YHH8vyd3, 0, m, &cIf_YHH8vyd3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NBRePqwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YHH8vyd3, 1, m, &cIf_YHH8vyd3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PLB5CFlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UROws83r, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_supEZNyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UROws83r, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Qi42PV8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cHmwINl7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_kQGzDWjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nu92up47_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_SoXrjj2F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PwTkuLrk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PwTkuLrk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_N5DcpNcF, 1, m, &cDelay_N5DcpNcF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rVq3NeQw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_N5DcpNcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N5DcpNcF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Qi42PV8y, 0, m, &cIf_Qi42PV8y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PwTkuLrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N5DcpNcF, 0, m, &cDelay_N5DcpNcF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rVq3NeQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N5DcpNcF, 0, m, &cDelay_N5DcpNcF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ysIkndrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OfgCaJr1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W2om1JaY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_zAZChsvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J9Xy9nq7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kgzMwyH7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kgzMwyH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SoXrjj2F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_J9Xy9nq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qi42PV8y, 1, m, &cIf_Qi42PV8y_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_W2om1JaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kQGzDWjz, 0, m, &cIf_kQGzDWjz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OfgCaJr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kQGzDWjz, 1, m, &cIf_kQGzDWjz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Nu92up47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bQ0kpNnr, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_cHmwINl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bQ0kpNnr, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_YPIwiWDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sINUk5J6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_fUiwAgbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vtDay2m6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_23HyU0ba_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_I86PnVcP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_I86PnVcP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RNKX6ckp, 1, m, &cDelay_RNKX6ckp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c3WLdw6H_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_RNKX6ckp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RNKX6ckp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YPIwiWDq, 0, m, &cIf_YPIwiWDq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_I86PnVcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RNKX6ckp, 0, m, &cDelay_RNKX6ckp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_c3WLdw6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RNKX6ckp, 0, m, &cDelay_RNKX6ckp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UDzaoJCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Px1hnbTe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2tuO6E8Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_08Gt7C9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jEuy6Nuq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_clSEuSWg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_clSEuSWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_23HyU0ba_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_jEuy6Nuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YPIwiWDq, 1, m, &cIf_YPIwiWDq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2tuO6E8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fUiwAgbF, 0, m, &cIf_fUiwAgbF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Px1hnbTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fUiwAgbF, 1, m, &cIf_fUiwAgbF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vtDay2m6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B0pySYnI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_sINUk5J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B0pySYnI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_tAkLA30h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fWapIbC1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_RJxrRSkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4hjH8xtR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_o10Aiekd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_05XSjj6B_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_05XSjj6B_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HQMG3m7y, 1, m, &cDelay_HQMG3m7y_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QGpbyzq1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_HQMG3m7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HQMG3m7y, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tAkLA30h, 0, m, &cIf_tAkLA30h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_05XSjj6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HQMG3m7y, 0, m, &cDelay_HQMG3m7y_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QGpbyzq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HQMG3m7y, 0, m, &cDelay_HQMG3m7y_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xO7FBSGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gI0dIcWS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ETj2Fjgi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GyQMi8Ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oi668Qco_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZCPpI305_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZCPpI305_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_o10Aiekd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_oi668Qco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tAkLA30h, 1, m, &cIf_tAkLA30h_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gI0dIcWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RJxrRSkX, 1, m, &cIf_RJxrRSkX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ETj2Fjgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RJxrRSkX, 0, m, &cIf_RJxrRSkX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4hjH8xtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y6ESugOK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_fWapIbC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y6ESugOK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KSGnFGrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_LdzoqQrt_sendMessage(_c, 0, m);
  cMsg_4asWwMT8_sendMessage(_c, 0, m);
  cMsg_mTL6KbGn_sendMessage(_c, 0, m);
  cMsg_JoHeOlVz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_OTuFklVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_LdzoqQrt_sendMessage(_c, 0, m);
  cMsg_Qi5SH1Tt_sendMessage(_c, 0, m);
  cMsg_xx8igZ4v_sendMessage(_c, 0, m);
  cMsg_aXPdczoi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MF4NSLVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_g9Rf5IDm_sendMessage(_c, 0, m);
  cMsg_Qi5SH1Tt_sendMessage(_c, 0, m);
  cMsg_JoHeOlVz_sendMessage(_c, 0, m);
  cMsg_1Yi9reGh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BsYFAULd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_g9Rf5IDm_sendMessage(_c, 0, m);
  cMsg_y7GJUgAl_sendMessage(_c, 0, m);
  cMsg_mTL6KbGn_sendMessage(_c, 0, m);
  cMsg_KcciVs0P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Hwy7osvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_4HeDoSOw_sendMessage(_c, 0, m);
  cMsg_aXPdczoi_sendMessage(_c, 0, m);
  cMsg_hVYE8D6z_sendMessage(_c, 0, m);
  cMsg_mTL6KbGn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_d4P1rBOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_4HeDoSOw_sendMessage(_c, 0, m);
  cMsg_KcciVs0P_sendMessage(_c, 0, m);
  cMsg_Qi5SH1Tt_sendMessage(_c, 0, m);
  cMsg_4htL5hQf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rspFzMaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SDcAhrDl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8Pomcwto_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9jinSTp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SDcAhrDl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8Pomcwto_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cO3x9aN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HZUL2knp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wdpKLAz6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IiMvYDVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HZUL2knp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wdpKLAz6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xY7Zvbf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_glTuV18D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JTUIITS5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Dz5hZ18L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_glTuV18D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JTUIITS5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LdzoqQrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_rspFzMaW_sendMessage(_c, 0, m);
  cMsg_IiMvYDVJ_sendMessage(_c, 0, m);
  cMsg_Dz5hZ18L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_g9Rf5IDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_9jinSTp3_sendMessage(_c, 0, m);
  cMsg_cO3x9aN0_sendMessage(_c, 0, m);
  cMsg_Dz5hZ18L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4HeDoSOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_9jinSTp3_sendMessage(_c, 0, m);
  cMsg_IiMvYDVJ_sendMessage(_c, 0, m);
  cMsg_xY7Zvbf1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6WEZNzCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Y5kmGigU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1G6smgVu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_myoKichI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Y5kmGigU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1G6smgVu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FBaX7lrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q6ZOKsUF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rMQvKfVH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PEIJ7WKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q6ZOKsUF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rMQvKfVH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2xMgZU0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CeLuwTZv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_etWyGKao_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vMM3HbIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CeLuwTZv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_etWyGKao_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Qi5SH1Tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_myoKichI_sendMessage(_c, 0, m);
  cMsg_PEIJ7WKL_sendMessage(_c, 0, m);
  cMsg_vMM3HbIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4asWwMT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_myoKichI_sendMessage(_c, 0, m);
  cMsg_FBaX7lrd_sendMessage(_c, 0, m);
  cMsg_2xMgZU0H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_y7GJUgAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_6WEZNzCb_sendMessage(_c, 0, m);
  cMsg_PEIJ7WKL_sendMessage(_c, 0, m);
  cMsg_2xMgZU0H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xD1ra5GQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zAZChsvj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ysIkndrV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_B27j5uXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zAZChsvj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ysIkndrV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fP8p20MC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_08Gt7C9r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UDzaoJCE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dLjb0XkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_08Gt7C9r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UDzaoJCE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8IXuqssM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GyQMi8Ck_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xO7FBSGT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XjmTEUPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GyQMi8Ck_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xO7FBSGT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KcciVs0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_xD1ra5GQ_sendMessage(_c, 0, m);
  cMsg_dLjb0XkE_sendMessage(_c, 0, m);
  cMsg_XjmTEUPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aXPdczoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_B27j5uXB_sendMessage(_c, 0, m);
  cMsg_fP8p20MC_sendMessage(_c, 0, m);
  cMsg_XjmTEUPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_JoHeOlVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_B27j5uXB_sendMessage(_c, 0, m);
  cMsg_dLjb0XkE_sendMessage(_c, 0, m);
  cMsg_8IXuqssM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_a50TGgrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qKFEDVZT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jbpJN7M0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uiidYKif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qKFEDVZT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jbpJN7M0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WYbHIdIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5WUg4Cpc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eD2FbFCE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_O2pbO4t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5WUg4Cpc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eD2FbFCE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PiXOjHD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rplHiNMH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2nJdIBkB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1piB4gCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rplHiNMH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2nJdIBkB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mTL6KbGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_uiidYKif_sendMessage(_c, 0, m);
  cMsg_O2pbO4t0_sendMessage(_c, 0, m);
  cMsg_1piB4gCJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xx8igZ4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_uiidYKif_sendMessage(_c, 0, m);
  cMsg_WYbHIdIb_sendMessage(_c, 0, m);
  cMsg_PiXOjHD6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4htL5hQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_a50TGgrH_sendMessage(_c, 0, m);
  cMsg_WYbHIdIb_sendMessage(_c, 0, m);
  cMsg_1piB4gCJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hVYE8D6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_6WEZNzCb_sendMessage(_c, 0, m);
  cMsg_FBaX7lrd_sendMessage(_c, 0, m);
  cMsg_vMM3HbIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_1Yi9reGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_a50TGgrH_sendMessage(_c, 0, m);
  cMsg_O2pbO4t0_sendMessage(_c, 0, m);
  cMsg_PiXOjHD6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_bqjKPRW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xhKoO9si_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_OoiM5YRI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AQ2bR2zH, 0, m, &cSlice_AQ2bR2zH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TWLP14vP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_AQ2bR2zH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rC36cThs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rC36cThs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_Jx7A37oC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rC36cThs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_rC36cThs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_L3khMqsC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_h9pszr9F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_O5WcNKU1, 0, m, &cSlice_O5WcNKU1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_q8ioqz1e_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_O5WcNKU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZvdODmV0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZvdODmV0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_rmbjTk5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZvdODmV0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ZvdODmV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3oT5hjM7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_q8ioqz1e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P3HLEH9n, 0, m, &cSlice_P3HLEH9n_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OoiM5YRI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_P3HLEH9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Q8Rnpfrh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Q8Rnpfrh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_220V1Jqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q8Rnpfrh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Q8Rnpfrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fs73XspK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_TWLP14vP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NEoq435u, 0, m, &cSlice_NEoq435u_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Dzky21rS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_NEoq435u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6e6XDICU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6e6XDICU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_g5BLJDGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6e6XDICU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_6e6XDICU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7DWzgcpA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Dzky21rS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VOU2CHCL, 0, m, &cSlice_VOU2CHCL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dQqzG6Bi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_VOU2CHCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZsBJgndV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZsBJgndV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_XvHvUROh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZsBJgndV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ZsBJgndV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ur2Rh5Jr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_xLtqE26B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1fifEUc0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1fifEUc0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eSX8jz2e, 1, m, &cDelay_eSX8jz2e_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_duzacJxs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_eSX8jz2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eSX8jz2e, m);
  cMsg_GBBRbgGe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_1fifEUc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eSX8jz2e, 0, m, &cDelay_eSX8jz2e_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_duzacJxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eSX8jz2e, 0, m, &cDelay_eSX8jz2e_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_WlxC5ed9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UGMok14j, HV_BINOP_SUBTRACT, 0, m, &cBinop_UGMok14j_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_zuIYvkys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PkXnIeAe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_l8oB29G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PkXnIeAe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_ouK9S1KB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WlxC5ed9, 0, m, &cVar_WlxC5ed9_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_rotnfrtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fRIxZJjt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LGMTq4nl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kLetmaVr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UGMok14j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wx1LBhlt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Wx1LBhlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8Ro05PIT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8Ro05PIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dkt7H96A_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_E0E4UOks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fNzNZFOQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ApCY9a0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2ApCY9a0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c03AdUuv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_fNzNZFOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zuIYvkys, 1, m, &cIf_zuIYvkys_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_s89ZcETr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l8oB29G0, 1, m, &cIf_l8oB29G0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_c03AdUuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zuIYvkys, 0, m, &cIf_zuIYvkys_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dkt7H96A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l8oB29G0, 0, m, &cIf_l8oB29G0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kLetmaVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WlxC5ed9, 0, m, &cVar_WlxC5ed9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fRIxZJjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_LGMTq4nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UGMok14j, HV_BINOP_SUBTRACT, 1, m, &cBinop_UGMok14j_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PkXnIeAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IjH9wthD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_dQqzG6Bi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uPURAV4R, 0, m, &cSlice_uPURAV4R_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_uPURAV4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UKb8RdOy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UKb8RdOy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_k6Y8dNux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UKb8RdOy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_UKb8RdOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pu57HRiY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cJwfOaTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qi3CztTI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HZ7FFh8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VFSkVAJK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_gvHfpo3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FnuJQHRA, 0, m, &cVar_FnuJQHRA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xhKoO9si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2fDiwNIV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_u374dMwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y5o85hxS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_rUuxlmkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xLtqE26B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_GBBRbgGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pbqNZFGQ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_y5o85hxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pbqNZFGQ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_GIqzkNrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_hauiRKJw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hauiRKJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u1l1SnQx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_u1l1SnQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j5S8jlwG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_z0YDg9jS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tWGQwAj3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aHEujlDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fhTOrb2x, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BCniOfpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1WnE3hWo, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_b9eYlJRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HUTQCdhU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_S5pAySuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_R4KhDNRS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h9pszr9F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ncQDjVor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_R4KhDNRS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h9pszr9F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_es3X3pCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qw1oOd7z, 0, m, &cVar_qw1oOd7z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7lJH6zmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_R4KhDNRS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h9pszr9F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_RER5qTVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_R4KhDNRS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h9pszr9F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_sRPV4efD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_R4KhDNRS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h9pszr9F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_PvSvbmbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_K3L7cDVs, 0, m, &cVar_K3L7cDVs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ovuXDhRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Bp12rv1s, 0, m, &cVar_Bp12rv1s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KPE6WbBU, 0, m, &cVar_KPE6WbBU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ufaOmK46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_es3X3pCb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EdK3EMNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ZxGTACkV, 0, m, &cVar_ZxGTACkV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tWGQwAj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_R4KhDNRS_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h9pszr9F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_PavbT31b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_z0YDg9jS, 0, m, &cVar_z0YDg9jS_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_HUTQCdhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Bhgo4rlB_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_tRwnpZbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CJfbewjo, 0, m, &cVar_CJfbewjo_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_JMDq8a2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_es3X3pCb_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_VpYjGlCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K3L7cDVs, 0, m, &cVar_K3L7cDVs_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Y38LknwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UdYKh2S1, 0, m, &cVar_UdYKh2S1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N2e0gyY9, 0, m, &cVar_N2e0gyY9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_21FAwV3k, 0, m, &cVar_21FAwV3k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hx3Wvl5Y, 0, m, &cVar_Hx3Wvl5Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CnfQq3nG, 0, m, &cVar_CnfQq3nG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cYsHAiuv, 0, m, &cVar_cYsHAiuv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jx7A37oC, 0, m, &cVar_Jx7A37oC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rmbjTk5E, 0, m, &cVar_rmbjTk5E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_220V1Jqj, 0, m, &cVar_220V1Jqj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_g5BLJDGn, 0, m, &cVar_g5BLJDGn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XvHvUROh, 0, m, &cVar_XvHvUROh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k6Y8dNux, 0, m, &cVar_k6Y8dNux_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_urDVnMk7_sendMessage);
  cMsg_EdK3EMNa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_GjHBESxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZxGTACkV, 0, m, &cVar_ZxGTACkV_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_6KQH6Ilx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bp12rv1s, 0, m, &cVar_Bp12rv1s_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_zJ9c7FPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KPE6WbBU, 0, m, &cVar_KPE6WbBU_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_lCdH0NQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hP2cPhAb, 0, m, &cVar_hP2cPhAb_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_2xW5sHXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lP2XrYJV, 0, m, &cVar_lP2XrYJV_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_EddwNtx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_7bnmjmpH_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_F2zboOao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_e3TZAFXD_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I2dV3F2u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AZb2Ioax_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_aOq7EAxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KADHKFkT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yrpdvJ1o_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_yaMSJyND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xlCVP3QY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_L3khMqsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HMnAlBuC, 0, m, &cVar_HMnAlBuC_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_7DWzgcpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bqjKPRW6, 0, m, &cVar_bqjKPRW6_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_fs73XspK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_gvHfpo3B_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_3oT5hjM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CckwPojq_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u374dMwV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rUuxlmkh_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ur2Rh5Jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E0E4UOks_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s89ZcETr_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_pu57HRiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GIqzkNrk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_tKopam3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z0YDg9jS, 0, m, &cVar_z0YDg9jS_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_dUFlVDaW, VIf(I0));
    __hv_varread_f(&sVarf_zpiBc2Bb, VOf(Bf0));
    __hv_varread_f(&sVarf_g020HGC0, VOf(Bf1));
    __hv_varread_f(&sVarf_6cLlfcLo, VOf(Bf2));
    __hv_varread_f(&sVarf_CYm8S8jK, VOf(Bf3));
    __hv_varread_f(&sVarf_nkemkiYN, VOf(Bf4));
    __hv_varread_f(&sVarf_9nLDRCuT, VOf(Bf5));
    __hv_varread_f(&sVarf_XTSiRri1, VOf(Bf6));
    __hv_varwrite_f(&sVarf_DflRtNEn, VIf(I0));
    __hv_varread_f(&sVarf_Yrlc2z5P, VOf(Bf7));
    __hv_line_f(&sLine_q8MkeRKO, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Uhee2Aq0, VOf(Bf9));
    __hv_line_f(&sLine_otOWOpJ7, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_YTGM1J0y, VOf(Bf8));
    __hv_line_f(&sLine_XsnCBmlt, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_CYm8S8jK, VIf(Bf11));
    __hv_varread_f(&sVarf_DflRtNEn, VOf(Bf11));
    __hv_line_f(&sLine_xYl5Su7R, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_aLQuIkHV, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_M5ttHUpD, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_nkemkiYN, VIf(Bf10));
    __hv_line_f(&sLine_bQAebMe3, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_MqfmrIxs, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_l0OzIrTy, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_9nLDRCuT, VIf(Bf10));
    __hv_line_f(&sLine_1IXBNWJd, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_IPN5JjOz, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_tHxJObVu, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_XTSiRri1, VIf(Bf10));
    __hv_varwrite_f(&sVarf_Yrlc2z5P, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Uhee2Aq0, VIf(Bf1));
    __hv_varwrite_f(&sVarf_YTGM1J0y, VIf(Bf2));
    sEnv_process(this, &sEnv_R9UclOj1, VIf(Bf3), &sEnv_R9UclOj1_sendMessage);
    sEnv_process(this, &sEnv_xgqaJSNm, VIf(I0), &sEnv_xgqaJSNm_sendMessage);
    __hv_line_f(&sLine_LzW3mqdc, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_Q0PVSnmY, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_6AAo6b07, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_UU6FMGPQ, VOf(Bf3));
    __hv_line_f(&sLine_mzjCEywJ, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_zpiBc2Bb, VIf(Bf0));
    __hv_varwrite_f(&sVarf_UU6FMGPQ, VIf(Bf4));
    __hv_varwrite_f(&sVarf_tP7b94Ti, VIf(Bf5));
    __hv_varwrite_f(&sVarf_m82oJCCs, VIf(Bf6));
    __hv_varread_f(&sVarf_m82oJCCs, VOf(Bf6));
    __hv_line_f(&sLine_i0nzeinK, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_6cLlfcLo, VIf(Bf4));
    __hv_varread_f(&sVarf_tP7b94Ti, VOf(Bf4));
    __hv_line_f(&sLine_BH9kx8YD, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_g020HGC0, VIf(Bf4));
    __hv_varwrite_f(&sVarf_Iwd3uIhX, VIf(Bf2));
    __hv_varwrite_f(&sVarf_a4ow5OCS, VIf(I1));
    __hv_varread_f(&sVarf_bHwBV4fs, VOf(Bf2));
    __hv_varread_f(&sVarf_eDiuu7Ph, VOf(Bf4));
    __hv_varread_f(&sVarf_qV6eVnEH, VOf(Bf0));
    __hv_varread_f(&sVarf_vl1f6p4D, VOf(Bf5));
    __hv_varread_f(&sVarf_j5kPoMkV, VOf(Bf3));
    __hv_varread_f(&sVarf_9pGJxgP9, VOf(Bf6));
    __hv_varread_f(&sVarf_54FyV2DG, VOf(Bf1));
    __hv_varwrite_f(&sVarf_WTMCRSED, VIf(I1));
    __hv_varread_f(&sVarf_W4wL8TVd, VOf(Bf10));
    __hv_line_f(&sLine_bQ0kpNnr, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_9u7Xsd1z, VOf(Bf7));
    __hv_line_f(&sLine_B0pySYnI, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_hD7cnPuL, VOf(Bf11));
    __hv_line_f(&sLine_Y6ESugOK, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_vl1f6p4D, VIf(Bf12));
    __hv_varread_f(&sVarf_WTMCRSED, VOf(Bf12));
    __hv_line_f(&sLine_EeBrS2vd, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_5rRzxRcN, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_qQ7AsD85, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_j5kPoMkV, VIf(Bf9));
    __hv_line_f(&sLine_QzJkzyZe, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_bkBl3tvW, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_WzQRmHWI, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_9pGJxgP9, VIf(Bf9));
    __hv_line_f(&sLine_EYFosEBW, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_80XnqXPw, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_UROws83r, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_54FyV2DG, VIf(Bf9));
    __hv_varwrite_f(&sVarf_W4wL8TVd, VIf(Bf2));
    __hv_varwrite_f(&sVarf_9u7Xsd1z, VIf(Bf4));
    __hv_varwrite_f(&sVarf_hD7cnPuL, VIf(Bf0));
    sEnv_process(this, &sEnv_ouK9S1KB, VIf(Bf5), &sEnv_ouK9S1KB_sendMessage);
    sEnv_process(this, &sEnv_rotnfrtt, VIf(I1), &sEnv_rotnfrtt_sendMessage);
    __hv_line_f(&sLine_IjH9wthD, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_pbqNZFGQ, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_j5S8jlwG, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_W0lDwF0V, VOf(Bf5));
    __hv_line_f(&sLine_VFSkVAJK, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_bHwBV4fs, VIf(Bf2));
    __hv_varwrite_f(&sVarf_W0lDwF0V, VIf(Bf3));
    __hv_varwrite_f(&sVarf_1V7xYAm5, VIf(Bf6));
    __hv_varwrite_f(&sVarf_HY0DRRJZ, VIf(Bf1));
    __hv_varread_f(&sVarf_HY0DRRJZ, VOf(Bf1));
    __hv_line_f(&sLine_2fDiwNIV, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_qV6eVnEH, VIf(Bf3));
    __hv_varread_f(&sVarf_1V7xYAm5, VOf(Bf3));
    __hv_line_f(&sLine_Qi3CztTI, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_eDiuu7Ph, VIf(Bf3));
    __hv_varwrite_f(&sVarf_cjb2dp9x, VIf(Bf0));
    __hv_varread_f(&sVarf_dUFlVDaW, VOf(Bf0));
    __hv_line_f(&sLine_1WnE3hWo, VOf(Bf3));
    __hv_varread_f(&sVarf_Iwd3uIhX, VOf(Bf2));
    __hv_line_f(&sLine_fhTOrb2x, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_a4ow5OCS, VOf(Bf2));
    __hv_varread_f(&sVarf_cjb2dp9x, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
